@@ -1,19 +1,12 @@
 import os
-import sys 
 import pkg_resources
+import yaml
 
 def init():
     def get_template_path(template_name):
         relative_path = os.path.join("templates", template_name)
         return pkg_resources.resource_filename("src", relative_path)
     
-    def is_cwd_empty():
-        files_and_directories = os.listdir()
-        return len(files_and_directories) == 0
-    
-    if not is_cwd_empty():
-        print("The current directory is not empty. Please run this command in an empty directory.")
-        sys.exit(1)
 
     print("Current working dir: ", os.getcwd())
     print(f"Template: {get_template_path('new-project/project.yml')}")
@@ -32,3 +25,22 @@ def init():
     for key, value in project_info.items():
         print(f"{key}: {value}")
 
+    with open(get_template_path('new-project/project.yml'), 'r') as stream:
+        try:
+            data = yaml.safe_load(stream)
+            data['name'] = project_info['name']
+            data['version'] = project_info['version']
+            data['description'] = project_info['description']
+            data['author'] = project_info['author']
+            data['license'] = project_info['license']
+
+        except yaml.YAMLError as exc:
+            print(exc)
+            data = {}
+
+    # Write the yaml back to the filesystem
+    with open("./project.yaml", 'w+') as stream:
+        try:
+            yaml.dump(data, stream)
+        except yaml.YAMLError as exc:
+            print(exc)
